@@ -7,7 +7,7 @@
 # Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
 # 2006, 2007, 2008, 2009, 2010, 2011 Comite Reseau des Universites
 # Copyright (c) 2011, 2012, 2013, 2014, 2015, 2016, 2017 GIP RENATER
-# Copyright 2018, 2021, 2022, 2023 The Sympa Community. See the
+# Copyright 2018, 2021, 2022, 2023, 2024 The Sympa Community. See the
 # AUTHORS.md file at the top-level directory of this distribution and at
 # <https://github.com/sympa-community/sympa.git>.
 #
@@ -63,8 +63,6 @@ sub connect {
     } else {
         $self->__dbh->func(5000, 'busy_timeout');
     }
-    # Create a temoprarhy view "dual" for portable SQL statements.
-    $self->__dbh->do(q{CREATE TEMPORARY VIEW dual AS SELECT 'X' AS dummy;});
 
     # Create a function MD5().
     $self->__dbh->func(
@@ -332,9 +330,8 @@ sub drop_field {
         return $report;
     }
 
-    unless (
-        $self->do_query("ALTER TABLE %s DROP COLUMN %s", $table, $field)
-    ) {
+    unless ($self->do_query("ALTER TABLE %s DROP COLUMN %s", $table, $field))
+    {
         $log->syslog('err',
             'Could not delete field %s from table %s in database %s',
             $field, $table, $self->{'db_name'});
