@@ -55,6 +55,21 @@ sub instance {
         unless $self = Sympa::Database->new($db_conf->{'db_type'}, %$db_conf)
         and $self->connect;
 
+    # Compatibility concern.
+    # - Create a temporary view "dual" for portable SQL statements.
+    if (ref $self eq 'Sympa::DatabaseDriver::PostgreSQL') {
+        # Note: PostgreSQL <= 8.0.x didn't support temporary view but >= 7.3.x
+        #   supported CREATE OR REPLACE statement.
+        defined $self->__dbh->do(
+            q{CREATE TEMPORARY VIEW dual AS SELECT 'X'::varchar(1) AS dummy;})
+            or $self->__dbh->do(
+            q{CREATE OR REPLACE VIEW dual AS SELECT 'X'::varchar(1) AS dummy;}
+            );
+    } elsif (ref $self eq 'Sympa::DatabaseDriver::SQLite') {
+        $self->__dbh->do(
+            q{CREATE TEMPORARY VIEW dual AS SELECT 'X' AS dummy;});
+    }
+
     # At once connection succeeded, we keep trying to connect.
     # Unless in a web context, because we can't afford long response time on
     # the web interface.
