@@ -79,11 +79,11 @@ our %list_option = (
     'remove_bouncers' => {'gettext_id' => 'remove bouncing users'},
     'notify_bouncers' => {'gettext_id' => 'send notify to bouncing users'},
 
-    # pictures_feature, dkim_feature, merge_feature,
+    # pictures_feature, dkim_feature, personalization_feature,
     # inclusion_notification_feature, tracking.delivery_status_notification,
     # tracking.message_disposition_notification
     'on' => {'gettext_id' => 'enabled'},
-    # pictures_feature, dkim_feature, merge_feature,
+    # pictures_feature, dkim_feature, personalization_feature,
     # inclusion_notification_feature, tracking.delivery_status_notification,
     # tracking.message_disposition_notification, update_db_field_types
     'off' => {'gettext_id' => 'disabled'},
@@ -106,6 +106,14 @@ our %list_option = (
     'one'  => {'gettext_id' => 'one level'},
     'sub'  => {'gettext_id' => 'subtree'},
 
+    # include_ldap_2level_query.deref2, include_ldap_2level_query.deref1,
+    # include_ldap_query.deref
+    'never' => {'gettext_id' => 'never'},
+    'search' =>
+        {'gettext_id' => 'in searching subordinates of the base object'},
+    'find'   => {'gettext_id' => 'in locating the base object'},
+    'always' => {'gettext_id' => 'always'},
+
     # include_ldap_query.use_tls, include_ldap_2level_query.use_tls,
     # include_ldap_ca.use_tls, include_ldap_2level_ca.use_tls
     'starttls' => {'gettext_id' => 'use STARTTLS'},
@@ -196,7 +204,7 @@ our %list_option = (
     'smime_authenticated_messages' =>
         {'gettext_id' => 'authenticated by S/MIME signature'},
     'dkim_authenticated_messages' =>
-        {'gettext_id' => 'authenticated by DKIM signature'},
+        {'gettext_id' => 'with successfully verified DKIM signature'},
     'editor_validated_messages' => {'gettext_id' => 'approved by moderator'},
     'any'                       => {'gettext_id' => 'any messages'},
 
