@@ -1,6 +1,5 @@
 # -*- indent-tabs-mode: nil; -*-
 # vim:ft=perl:et:sw=4
-# $Id$
 
 # Sympa - SYsteme de Multi-Postage Automatique
 #
@@ -8,8 +7,8 @@
 # Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
 # 2006, 2007, 2008, 2009, 2010, 2011 Comite Reseau des Universites
 # Copyright (c) 2011, 2012, 2013, 2014, 2015, 2016, 2017 GIP RENATER
-# Copyright 2017, 2019, 2020 The Sympa Community. See the AUTHORS.md
-# file at the top-level directory of this distribution and at
+# Copyright 2017, 2019, 2020, 2022 The Sympa Community. See the
+# AUTHORS.md file at the top-level directory of this distribution and at
 # <https://github.com/sympa-community/sympa.git>.
 #
 # This program is free software; you can redistribute it and/or modify
@@ -105,8 +104,10 @@ sub new {
             Sympa::Tools::Data::decode_custom_attribute($serialized);
     }
 
-    if ($self->{email}
-        and not(defined $self->{gecos} and length $self->{gecos})) {
+    #FIXME:Meddlesomeness to be removed.
+    if (    $self->{action} ne 'set'
+        and $self->{email}
+        and not length($self->{gecos} // '')) {
         my $user = Sympa::User->new($self->{email});
         $self->{gecos} = $user->gecos if $user and $user->gecos;
     }
