@@ -1,6 +1,5 @@
 # -*- indent-tabs-mode: nil; -*-
 # vim:ft=perl:et:sw=4
-# $Id$
 
 # Sympa - SYsteme de Multi-Postage Automatique
 #
@@ -202,10 +201,15 @@ sub _twist {
     my %result =
         (added => 0, deleted => 0, updated => 0, kept => 0, held => 0);
     my $succeeded = 0;
+    my $skipped   = 0;
     foreach my $ds (@{$dss || []}) {
         $lock_fh->extend;
 
-        next unless $ds->is_allowed_to_sync;
+        unless ($ds->is_allowed_to_sync) {
+            $skipped++;
+            next;
+        }
+
         my %res = _update_users($ds, $start_time);
         unless (%res) {
             $self->add_stash(
@@ -274,7 +278,7 @@ sub _twist {
         # Special treatment for Sympa::DataSource::List.
         _expire_inclusion_table($list, $role, $last_start_time);
     } else {
-        # Part(s) or entire data sources failed.
+        # Part(s) or entire data sources failed or simply skipped.
         $lock_fh->extend;
 
         # Estimate number of held users, i.e. users not decided to
@@ -334,8 +338,14 @@ sub _twist {
         $self->add_stash($request, 'notice', 'include_performed',
             {listname => $list->{'name'}, role => $role, result => {%result}}
         );
+    } elsif ($skipped == scalar @$dss) {
+        # All data sources skipped.
+        $log->syslog('info', '%s: Skipped');
+        $self->add_stash($request, 'notice', 'include_skip',
+            {listname => $list->{'name'}, role => $role, result => {%result}}
+        );
     } elsif ($succeeded) {
-        # Part(s) of data sources failed.
+        # Part(s) of data sources succeeded: The others failed or skipped.
         $log->syslog(
             'info',   '%s: Partial, %d added, %d held, %d updated',
             $request, @result{qw(added held updated)}
@@ -711,7 +721,7 @@ sub _update_custom_attribute {
 
         my $member = $list->get_list_member($email);
         next unless $member;
-        my $ca = $member->{custom_attribute} || {};
+        my $ca = $member->{attrib} || {};
 
         my $changed;
         foreach my $key (sort keys %{$ca_update || {}}) {
@@ -726,7 +736,7 @@ sub _update_custom_attribute {
         }
         next unless $changed;
 
-        $list->update_list_member($email, custom_attribute => $ca_update);
+        $list->update_list_member($email, attrib => $ca_update);
         $updated++;
     }
 
