@@ -1,6 +1,5 @@
 # -*- indent-tabs-mode: nil; -*-
 # vim:ft=perl:et:sw=4
-# $Id$
 
 # Sympa - SYsteme de Multi-Postage Automatique
 #
@@ -8,7 +7,7 @@
 # Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
 # 2006, 2007, 2008, 2009, 2010, 2011 Comite Reseau des Universites
 # Copyright (c) 2011, 2012, 2013, 2014, 2015, 2016, 2017 GIP RENATER
-# Copyright 2018, 2019, 2021 The Sympa Community. See the
+# Copyright 2018, 2019, 2021, 2022 The Sympa Community. See the
 # AUTHORS.md file at the top-level directory of this distribution and at
 # <https://github.com/sympa-community/sympa.git>.
 #
@@ -84,7 +83,7 @@ sub _twist {
 
     my @stash;
     $list->add_list_member(
-        {email => $email, gecos => $comment, custom_attribute => $ca},
+        {email => $email, gecos => $comment, ($ca ? (attrib => $ca) : ())},
         stash => \@stash);
     foreach my $report (@stash) {
         $self->add_stash($request, @$report);
