@@ -1,6 +1,5 @@
 # -*- indent-tabs-mode: nil; -*-
 # vim:ft=perl:et:sw=4
-# $Id$
 
 # Sympa - SYsteme de Multi-Postage Automatique
 #
@@ -38,6 +37,7 @@ use Conf;
 use Sympa::Language;
 use Sympa::Log;
 use Sympa::Spindle::ProcessTemplate;
+use Sympa::Tools::Text;
 
 use base qw(Sympa::Spindle);
 
@@ -155,6 +155,8 @@ sub _distribute_digest {
             #FIXME: Might be extracted from Date:.
             'month'      => POSIX::strftime("%Y-%m", localtime $time),
             'message_id' => $message->{'message_id'},
+            permalink_id =>
+                Sympa::Tools::Text::permalink_id($message->{message_id}),
         };
         push @all_msg, $msg;
 
