@@ -1,6 +1,5 @@
 # -*- indent-tabs-mode: nil; -*-
 # vim:ft=perl:et:sw=4
-# $Id$
 
 # Sympa - SYsteme de Multi-Postage Automatique
 #
@@ -8,8 +7,8 @@
 # Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
 # 2006, 2007, 2008, 2009, 2010, 2011 Comite Reseau des Universites
 # Copyright (c) 2011, 2012, 2013, 2014, 2015, 2016, 2017 GIP RENATER
-# Copyright 2017, 2019 The Sympa Community. See the AUTHORS.md file at
-# the top-level directory of this distribution and at
+# Copyright 2017, 2019, 2020, 2022 The Sympa Community. See the
+# AUTHORS.md file at the top-level directory of this distribution and at
 # <https://github.com/sympa-community/sympa.git>.
 #
 # This program is free software; you can redistribute it and/or modify
@@ -131,7 +130,7 @@ sub _twist {
     # They should be migrated.
     if ($message and $message->{checksum}) {
         $log->syslog('err',
-            '%s: Message with old format.  Run upgrade_send_spool.pl',
+            '%s: Message with old format.  Run \'sympa upgrade incoming\'',
             $message);
         return 0;    # Skip
     }
@@ -199,10 +198,8 @@ sub _twist {
 
     # Load spam status.
     $message->check_spam_status;
-    # Check DKIM signatures.
-    $message->check_dkim_signature;
-    # Check ARC seals
-    $message->check_arc_chain;
+    # Check Authentication-Results fields, DKIM signatures and/or ARC seals.
+    $message->aggregate_authentication_results;
     # Check S/MIME signature.
     $message->check_smime_signature;
     # Decrypt message.  On success, check nested S/MIME signature.
