@@ -1,6 +1,5 @@
 # -*- indent-tabs-mode: nil; -*-
 # vim:ft=perl:et:sw=4
-# $Id$
 
 # Sympa - SYsteme de Multi-Postage Automatique
 #
@@ -8,7 +7,7 @@
 # Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
 # 2006, 2007, 2008, 2009, 2010, 2011 Comite Reseau des Universites
 # Copyright (c) 2011, 2012, 2013, 2014, 2015, 2016, 2017 GIP RENATER
-# Copyright 2017, 2018, 2020, 2021 The Sympa Community. See the
+# Copyright 2017, 2018, 2020, 2021, 2022 The Sympa Community. See the
 # AUTHORS.md file at the top-level directory of this distribution and at
 # <https://github.com/sympa-community/sympa.git>.
 #
@@ -349,6 +348,11 @@ sub _get_option_description {
     return $option;
 }
 
+sub _permalink_id {
+    my $string = shift;
+    return Sympa::Tools::Text::permalink_id($string);
+}
+
 sub _url_func {
     my $self   = shift;
     my $is_abs = shift;
@@ -432,6 +436,7 @@ sub parse {
             url_abs => [sub { shift; $self->_url_func(1, $data, @_) }, 1],
             url_rel => [sub { shift; $self->_url_func(0, $data, @_) }, 1],
             canonic_email => \&Sympa::Tools::Text::canonic_email,
+            permalink_id  => [\&_permalink_id, 0],
         }
     };
 
@@ -769,6 +774,13 @@ If parameter value is added to the description.  False by default.
 
 =back
 
+=item permalink_id
+
+Calculate permalink ID from message ID.
+
+Note:
+This filter was introduced by Sympa 6.2.71b.
+
 =item qencode
 
 Encode string by MIME header encoding.
