@@ -8,8 +8,8 @@
 # Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
 # 2006, 2007, 2008, 2009, 2010, 2011 Comite Reseau des Universites
 # Copyright (c) 2011, 2012, 2013, 2014, 2015, 2016, 2017 GIP RENATER
-# Copyright 2018 The Sympa Community. See the AUTHORS.md file at the
-# top-level directory of this distribution and at
+# Copyright 2018, 2023 The Sympa Community. See the
+# AUTHORS.md file at the top-level directory of this distribution and at
 # <https://github.com/sympa-community/sympa.git>.
 #
 # This program is free software; you can redistribute it and/or modify
@@ -669,11 +669,7 @@ sub update_global_user {
     my @set_list;
 
     while (($field, $value) = each %{$values}) {
-        unless ($map_field{$field}) {
-            $log->syslog('err',
-                'Unknown field %s in map_field internal error', $field);
-            next;
-        }
+        next unless $map_field{$field};
         my $set;
 
         if ($numeric_field{$map_field{$field}}) {
